@@ -1,4 +1,5 @@
-from colorama import Fore, init as init_colors
+from colorama import Fore
+from colorama import init as init_colors
 
 colors = dict(
     red=Fore.RED,
